@@ -71,8 +71,7 @@ for app in get_apps():
         attrs = {
             'fixtures': [],
             'smoknur_path': path,
-            'test': test_runner,
-            'reset_sequences': True
+            'test': test_runner
         }
         for file_ in sorted(os.listdir(path)):
             if file_.endswith('.json'):
